@@ -12,7 +12,7 @@ CONTAINER_NAME="ladybugtools/lbt-honeybee"
 
 echo "PyPi Deployment..."
 echo "Building distribution"
-python setup.py sdist bdist_wheel
+python -m build
 echo "Pushing new version to PyPi"
 twine upload dist/* -u $PYPI_USERNAME -p $PYPI_PASSWORD
 
